@@ -47,15 +47,15 @@
 #' Stata's cmcmmixlogit.
 #' @param correlation Set to `TRUE` to account for correlation across random
 #' parameters (correlated heterogeneity). Defaults to `FALSE`.
-#' @param startParBounds sets the `lower` and `upper` bounds for the starting
-#' parameters for each optimization run, which are generated by
+#' @param startValBounds sets the `lower` and `upper` bounds for the starting
+#' parameter values for each optimization run, which are generated by
 #' `runif(n, lower, upper)`. Defaults to `c(-1, 1)`.
 #' @param startVals is vector of values to be used as starting values for the
 #' optimization. Only used for the first run if `numMultiStarts > 1`. Defaults
 #' to `NULL`.
 #' @param numMultiStarts is the number of times to run the optimization loop,
 #' each time starting from a different random starting point for each parameter
-#' between `startParBounds`. Recommended for non-convex models, such as WTP
+#' between `startValBounds`. Recommended for non-convex models, such as WTP
 #' space models and mixed logit models. Defaults to `1`.
 #' @param useAnalyticGrad Set to `FALSE` to use numerically approximated
 #' gradients instead of analytic gradients during estimation. For now, using
@@ -135,7 +135,7 @@
 #' |`probabilities`|Predicted probabilities. Not returned if `predict = FALSE`.|
 #' |`fitted.values`|Fitted values. Not returned if `predict = FALSE`.|
 #' |`residuals`|Residuals. Not returned if `predict = FALSE`.|
-#' |`startPars`|The starting values used.|
+#' |`startVals`|The starting values used.|
 #' |`multistartNumber`|The multistart run number for this model.|
 #' |`multistartSummary`|A summary of the log-likelihood values for each multistart run (if more than one multistart was used).|
 #' |`time`|The user, system, and elapsed time to run the optimization.|
@@ -207,7 +207,7 @@ logitr <- function(
   clusterID       = NULL,
   robust          = FALSE,
   correlation     = FALSE,
-  startParBounds  = c(-1, 1),
+  startValBounds  = c(-1, 1),
   startVals       = NULL,
   numMultiStarts  = 1,
   useAnalyticGrad = TRUE,
@@ -318,7 +318,7 @@ logitr <- function(
 
   modelInputs <- getModelInputs(
     data, outcome, obsID, pars, randPars, scalePar, randScale,
-    weights, panelID, clusterID, robust, startParBounds, startVals,
+    weights, panelID, clusterID, robust, startValBounds, startVals,
     numMultiStarts, useAnalyticGrad, scaleInputs, standardDraws, drawType,
     numDraws, numCores, vcov, predict, correlation, call, options
   )
