@@ -17,8 +17,8 @@
 logLik.logitr <- function(object, ...) {
   return(structure(
     object$logLik,
-    df    = object$n$pars,
-    null  = sum(object$freq * log(object$freq / object$n$obs)),
+    df = object$n$pars,
+    null = sum(object$freq * log(object$freq / object$n$obs)),
     class = "logLik"
   ))
 }
@@ -32,34 +32,34 @@ terms.logitr <- function(x, ...) {
 #' @rdname miscmethods.logitr
 #' @export
 coef.logitr <- function(object, ...) {
-    return(object$coefficients)
+  return(object$coefficients)
 }
 
 #' @rdname miscmethods.logitr
 #' @method coef summary.logitr
 #' @export
 coef.summary.logitr <- function(object, ...) {
-    return(object$coefTable)
+  return(object$coefTable)
 }
 
 #' @rdname miscmethods.logitr
 #' @export
-summary.logitr <- function (object, ...) {
-    object$modelInfoTable <- getModelInfoTable(object)
-    coefs <- stats::coef(object)
-    standErr <- se(object)
-    object$coefTable <- getCoefTable(coefs, standErr)
-    object$statTable <- getStatTable(object)
-    if (object$modelType == "mxl") {
-        object$randParSummary <- getRandParSummary(object)
-    }
-    class(object) <- c("summary.logitr", "logitr")
-    return(object)
+summary.logitr <- function(object, ...) {
+  object$modelInfoTable <- getModelInfoTable(object)
+  coefs <- stats::coef(object)
+  standErr <- se(object)
+  object$coefTable <- getCoefTable(coefs, standErr)
+  object$statTable <- getStatTable(object)
+  if (object$modelType == "mxl") {
+    object$randParSummary <- getRandParSummary(object)
+  }
+  class(object) <- c("summary.logitr", "logitr")
+  return(object)
 }
 
 #' @rdname miscmethods.logitr
 #' @export
-print.logitr <- function (
+print.logitr <- function(
   x,
   digits = max(3, getOption("digits") - 2),
   width = getOption("width"),
@@ -74,16 +74,22 @@ print.logitr <- function (
   if (x$n$multiStarts > 1) {
     modelRun <- getModelRun(x)
     cat(
-      "Results below are from run", modelRun, "multistart runs\n",
-      "as it had the largest log-likelihood value\n")
+      "Results below are from run",
+      modelRun,
+      "multistart runs\n",
+      "as it had the largest log-likelihood value\n"
+    )
     cat("\n")
   }
   # Print coefficients & log-likelihood
   if (!any(is.na(stats::coef(x)))) {
-      cat("Coefficients:\n")
-      print.default(
-        format(x$coefficients, digits = digits), print.gap = 2, quote = FALSE)
-      print(x$logLik)
+    cat("Coefficients:\n")
+    print.default(
+      format(x$coefficients, digits = digits),
+      print.gap = 2,
+      quote = FALSE
+    )
+    print(x$logLik)
   } else {
     cat("No coefficients\n")
   }
@@ -101,8 +107,12 @@ print.summary.logitr <- function(
   ...
 ) {
   cat("=================================================", "\n", sep = "")
-  if (is.null(x$date)) {x$date <- "date missing"}
-  if (is.null(x$version)) {x$date <- "version missing"}
+  if (is.null(x$date)) {
+    x$date <- "date missing"
+  }
+  if (is.null(x$version)) {
+    x$date <- "version missing"
+  }
   cat("\nModel estimated on:", x$date, "\n")
   cat("\nUsing logitr version:", x$version, "\n\n")
   cat("Call:\n")
@@ -125,9 +135,9 @@ print.summary.logitr <- function(
   stats::printCoefmat(x$coefTable, digits = digits)
   print(x$statTable)
   if (x$modelType == "mxl") {
-      cat("\n")
-      cat("Summary of 10k Draws for Random Coefficients:", "\n")
-      print(x$randParSummary)
+    cat("\n")
+    cat("Summary of 10k Draws for Random Coefficients:", "\n")
+    print(x$randParSummary)
   }
   invisible(x)
 }
@@ -139,13 +149,23 @@ getModelInfoTable <- function(object) {
   modelTime <- convertTime(object$time)
   algorithm <- object$options$algorithm
   modelInfoTable <- data.frame(c(
-    modelType, modelSpace, modelRun, object$iterations,
-    modelTime, algorithm, object$weightsUsed
+    modelType,
+    modelSpace,
+    modelRun,
+    object$iterations,
+    modelTime,
+    algorithm,
+    object$weightsUsed
   ))
   colnames(modelInfoTable) <- ""
   row.names(modelInfoTable) <- c(
-    "Model Type:", "Model Space:", "Model Run:", "Iterations:",
-    "Elapsed Time:", "Algorithm:", "Weights Used?:"
+    "Model Type:",
+    "Model Space:",
+    "Model Run:",
+    "Iterations:",
+    "Elapsed Time:",
+    "Algorithm:",
+    "Weights Used?:"
   )
   panelID <- object$inputs$panelID
   if (!is.null(panelID)) {
@@ -167,11 +187,11 @@ getModelInfoTable <- function(object) {
 }
 
 getCoefTable <- function(coefs, standErr) {
-    z <- coefs / standErr
-    p <- 2 * (1 - stats::pnorm(abs(z)))
-    coefTable <- cbind(coefs, standErr, z, p)
-    colnames(coefTable) <- c("Estimate", "Std. Error", "z-value", "Pr(>|z|)")
-    return(as.data.frame(coefTable))
+  z <- coefs / standErr
+  p <- 2 * (1 - stats::pnorm(abs(z)))
+  coefTable <- cbind(coefs, standErr, z, p)
+  colnames(coefTable) <- c("Estimate", "Std. Error", "z-value", "Pr(>|z|)")
+  return(as.data.frame(coefTable))
 }
 
 getStatTable <- function(object) {
@@ -180,13 +200,26 @@ getStatTable <- function(object) {
   mcR2 <- 1 - (object$logLik / object$nullLogLik)
   adjMcR2 <- 1 - ((object$logLik - object$n$pars) / object$nullLogLik)
   statTable <- data.frame(c(
-    object$logLik, object$nullLogLik, aic, bic, mcR2, adjMcR2, object$n$obs
+    object$logLik,
+    object$nullLogLik,
+    aic,
+    bic,
+    mcR2,
+    adjMcR2,
+    object$n$obs
   ))
   colnames(statTable) <- ""
   row.names(statTable) <- c(
-    "Log-Likelihood:", "Null Log-Likelihood:", "AIC:", "BIC:", "McFadden R2:",
-    "Adj McFadden R2:" , "Number of Observations:")
-  if (!is.null(object$n$clusters)) { # Added for backwards compatibility
+    "Log-Likelihood:",
+    "Null Log-Likelihood:",
+    "AIC:",
+    "BIC:",
+    "McFadden R2:",
+    "Adj McFadden R2:",
+    "Number of Observations:"
+  )
+  if (!is.null(object$n$clusters)) {
+    # Added for backwards compatibility
     if (object$n$clusters > 0) {
       statTable <- rbind(statTable, object$n$clusters)
       row.names(statTable)[nrow(statTable)] <- "Number of Clusters"
@@ -202,7 +235,12 @@ getRandParSummary <- function(object) {
   n$draws <- 10^4
   standardDraws <- getStandardDraws(parIDs, n$draws, 'halton')
   betaDraws <- makeBetaDraws(
-      stats::coef(object), parIDs, n, standardDraws, object$inputs$correlation)
+    stats::coef(object),
+    parIDs,
+    n,
+    standardDraws,
+    object$inputs$correlation
+  )
   randParSummary <- apply(betaDraws, 2, summary)
   # Add names to summary
   nIDs <- parIDs$n
@@ -217,18 +255,18 @@ getRandParSummary <- function(object) {
   randParSummary <- as.data.frame(t(randParSummary))
   # Set min and max values for unbounded distributions
   if (length(nIDs) > 0) {
-      randParSummary[nIDs,]$Min. <- -Inf
-      randParSummary[nIDs,]$Max. <- Inf
+    randParSummary[nIDs, ]$Min. <- -Inf
+    randParSummary[nIDs, ]$Max. <- Inf
   }
   if (length(lnIDs) > 0) {
-      randParSummary[lnIDs,]$Min. <- 0
-      randParSummary[lnIDs,]$Max. <- Inf
+    randParSummary[lnIDs, ]$Min. <- 0
+    randParSummary[lnIDs, ]$Max. <- Inf
   }
   if (length(cnIDs) > 0) {
-      randParSummary[cnIDs,]$Max. <- Inf
+    randParSummary[cnIDs, ]$Max. <- Inf
   }
   # Add names and drop fixed pars
-  randParSummary <- randParSummary[parIDs$r,]
+  randParSummary <- randParSummary[parIDs$r, ]
   row.names(randParSummary) <- names(parIDs$r)
   return(randParSummary)
 }
@@ -239,7 +277,10 @@ getModelType <- function(x) {
 
 getModelSpace <- function(x) {
   return(ifelse(
-    x$modelSpace == "pref", "Preference", "Willingness-to-Pay"))
+    x$modelSpace == "pref",
+    "Preference",
+    "Willingness-to-Pay"
+  ))
 }
 
 getModelRun <- function(x) {
@@ -281,8 +322,8 @@ se.logitr <- function(object, ...) {
 #' @export
 vcov.logitr <- function(object, ...) {
   if (!is.null(object$vcov)) {
-      # vcov was already computed during model estimation
-      return(object$vcov)
+    # vcov was already computed during model estimation
+    return(object$vcov)
   }
   if (is.null(object$data$clusterID) | object$inputs$robust == FALSE) {
     return(getCovarianceNonRobust(object$hessian))
@@ -291,10 +332,10 @@ vcov.logitr <- function(object, ...) {
 }
 
 getCovarianceNonRobust <- function(hessian) {
-  covariance <- hessian*NA
+  covariance <- hessian * NA
   tryCatch(
     {
-      covariance <- solve(-1*hessian)
+      covariance <- solve(-1 * hessian)
     },
     error = function(e) {}
   )
@@ -307,14 +348,14 @@ getCovarianceRobust <- function(object) {
   parSetup <- object$parSetup
   modelInputs <- list(
     logitFuncs = setLogitFunctions(object$modelSpace),
-    evalFuncs  = setEvalFunctions(object$modelType, inputs$useAnalyticGrad),
-    inputs     = inputs,
-    modelType  = object$modelType,
+    evalFuncs = setEvalFunctions(object$modelType, inputs$useAnalyticGrad),
+    inputs = inputs,
+    modelType = object$modelType,
     modelSpace = object$modelSpace,
-    n          = object$n,
-    parSetup   = parSetup,
-    parIDs     = object$parIDs,
-    panel      = !is.null(inputs$panelID),
+    n = object$n,
+    parSetup = parSetup,
+    parIDs = object$parIDs,
+    panel = !is.null(inputs$panelID),
     standardDraws = object$standardDraws,
     data_diff = makeDiffData(object$data, object$modelType)
   )
@@ -332,15 +373,17 @@ getCovarianceRobust <- function(object) {
   M <- t(diffMat) %*% diffMat
   M <- M * (numClusters / (numClusters - 1)) # small sample correction
   D <- getCovarianceNonRobust(object$hessian)
-  if (any(is.na(D))) { return(D) } # If there are NAs the next line will error
+  if (any(is.na(D))) {
+    return(D)
+  } # If there are NAs the next line will error
   return(D %*% M %*% D)
 }
 
-getClusterModelInputs <- function (indices, mi, i) {
-  X <- mi$data_diff$X[indices,]
+getClusterModelInputs <- function(indices, mi, i) {
+  X <- mi$data_diff$X[indices, ]
   # Cast to matrix in cases where there is 1 independent variable
   if (length(indices) == 1) {
-      X <- matrix(X, nrow = 1)
+    X <- matrix(X, nrow = 1)
   }
   mi$data_diff$X <- X
   mi$data_diff$scalePar <- mi$data_diff$scalePar[indices]
@@ -364,7 +407,7 @@ getClusterModelInputs <- function (indices, mi, i) {
 
 #' @rdname miscmethods.logitr
 #' @export
-print.logitr_wtp <- function (
+print.logitr_wtp <- function(
   x,
   digits = max(3, getOption("digits") - 2),
   width = getOption("width"),
@@ -405,7 +448,7 @@ fitted.logitr <- function(object, probs = NULL, ...) {
     probs <- stats::predict(object, type = "prob")
   }
   outcome <- object$data$outcome
-  fitted <- probs[which(outcome == 1),]
+  fitted <- probs[which(outcome == 1), ]
   names(fitted)[which(names(fitted) == 'predicted_prob')] <- "fitted_value"
   return(fitted)
 }
@@ -442,7 +485,7 @@ residuals.logitr <- function(object, fitted = NULL, ...) {
     fitted <- stats::fitted(object)
   }
   reps <- table(object$data$obsID)
-  residuals <- fitted[rep(seq_along(reps), reps),]
+  residuals <- fitted[rep(seq_along(reps), reps), ]
   resids <- object$data$outcome - residuals$fitted_value
   residuals$fitted_value <- NULL
   residuals$residual <- as.vector(resids)
@@ -478,15 +521,15 @@ residuals.logitr <- function(object, fitted = NULL, ...) {
 #' # Compute a confidence interval
 #' confint(mnl_pref)
 confint.logitr <- function(object, parm, level = 0.95, ...) {
-    draws <- getUncertaintyDraws(object, numDraws = 10^4)
-    lower <- (1 - level)/2
-    upper <- 1 - lower
-    df <- data.frame(
-        lower = apply(draws, 2, function(x) fquantile(x, lower, na.rm = TRUE)),
-        upper = apply(draws, 2, function(x) fquantile(x, upper, na.rm = TRUE))
-    )
-    names(df) <- c(paste(lower*100, "%"), paste(upper*100, "%"))
-    return(df)
+  draws <- getUncertaintyDraws(object, numDraws = 10^4)
+  lower <- (1 - level) / 2
+  upper <- 1 - lower
+  df <- data.frame(
+    lower = apply(draws, 2, function(x) fquantile(x, lower, na.rm = TRUE)),
+    upper = apply(draws, 2, function(x) fquantile(x, upper, na.rm = TRUE))
+  )
+  names(df) <- c(paste(lower * 100, "%"), paste(upper * 100, "%"))
+  return(df)
 }
 
 #' Construct Design Matrices
@@ -516,7 +559,7 @@ confint.logitr <- function(object, parm, level = 0.95, ...) {
 #' # Get the model.matrix design matrix
 #' model.matrix(mnl_pref)
 model.matrix.logitr <- function(object, ...) {
-    return(object$data$X)
+  return(object$data$X)
 }
 
 #' Extracting the Model Frame from a Formula or Fit
@@ -545,8 +588,185 @@ model.matrix.logitr <- function(object, ...) {
 #' # Get the model.frame data frame
 #' model.frame(mnl_pref)
 model.frame.logitr <- function(formula, ...) {
-    stats::model.frame.default(
-        formula$formula,
-        data = eval(formula$call$data, envir = parent.frame())
+  stats::model.frame.default(
+    formula$formula,
+    data = eval(formula$call$data, envir = parent.frame())
+  )
+}
+
+#' @rdname miscmethods.logitr
+#' @export
+print.logitr_validation <- function(x, ...) {
+  cat("=== LOGITR DATA VALIDATION ===\n\n")
+
+  # Basic data info
+  cat("Data Overview:\n")
+  cat("  Rows:", x$data_info$nrows, "\n")
+  cat("  Columns:", x$data_info$ncols, "\n")
+  cat("  Outcome variable:", x$data_info$outcome, "\n")
+  cat("  Observation ID:", x$data_info$obsID, "\n")
+  if (!is.null(x$data_info$pars)) {
+    cat("  Parameters:", paste(x$data_info$pars, collapse = ", "), "\n")
+  }
+  if (!is.null(x$data_info$scalePar)) {
+    cat("  Scale parameter:", x$data_info$scalePar, "\n")
+  }
+  if (!is.null(x$data_info$panelID)) {
+    cat("  Panel ID:", x$data_info$panelID, "\n")
+  }
+
+  # Summary statistics
+  if (!is.null(x$summary$total_observations)) {
+    cat("\nData Structure:\n")
+    cat("  Total observations:", x$summary$total_observations, "\n")
+    cat("  Total alternatives:", x$summary$total_alternatives, "\n")
+    cat("  Valid choices:", x$summary$valid_choices %||% "Unknown", "\n")
+
+    if (!is.null(x$summary$alternatives_per_obs)) {
+      cat("  Alternatives per observation:\n")
+      alt_table <- x$summary$alternatives_per_obs
+      for (i in seq_along(alt_table)) {
+        cat(
+          "    ",
+          names(alt_table)[i],
+          "alternatives:",
+          alt_table[i],
+          "observations\n"
+        )
+      }
+    }
+
+    if (!is.null(x$summary$individuals)) {
+      cat("  Panel structure:\n")
+      cat("    Individuals:", x$summary$individuals, "\n")
+      if (!is.null(x$summary$obs_per_individual)) {
+        obs_summary <- x$summary$obs_per_individual
+        cat(
+          "    Observations per individual: Min =",
+          obs_summary["Min."],
+          ", Max =",
+          obs_summary["Max."],
+          ", Mean =",
+          round(obs_summary["Mean"], 1),
+          "\n"
+        )
+      }
+    }
+  }
+
+  # Parameter information
+  if (!is.null(x$summary$parameter_info)) {
+    cat("\nParameter Information:\n")
+    for (par_name in names(x$summary$parameter_info)) {
+      par_info <- x$summary$parameter_info[[par_name]]
+      cat("  ", par_name, "(", par_info$type, "):")
+
+      if (par_info$type %in% c("character", "factor")) {
+        cat(" ", par_info$n_levels, "levels")
+        if (par_info$n_levels <= 5) {
+          cat(" -", paste(par_info$unique_values, collapse = ", "))
+        }
+      } else if (par_info$type == "numeric") {
+        cat(
+          " range [",
+          round(par_info$range[1], 3),
+          ",",
+          round(par_info$range[2], 3),
+          "]"
+        )
+      }
+
+      if (par_info$na_count > 0) {
+        cat(" (", par_info$na_count, "missing)")
+      }
+      cat("\n")
+    }
+  }
+
+  # Scale parameter information
+  if (!is.null(x$summary$scalePar_info)) {
+    cat("\nScale Parameter Information:\n")
+    scalePar_info <- x$summary$scalePar_info
+    cat("  ", scalePar_info$name, "(", scalePar_info$type, "):")
+    cat(
+      " range [",
+      round(scalePar_info$range[1], 3),
+      ",",
+      round(scalePar_info$range[2], 3),
+      "]"
     )
+    if (scalePar_info$na_count > 0) {
+      cat(" (", scalePar_info$na_count, "missing)")
+    }
+    cat("\n")
+  }
+
+  # Results section
+  cat("\n=== VALIDATION RESULTS ===\n")
+
+  if (length(x$errors) == 0 && length(x$warnings) == 0) {
+    cat("\u2713 Data validation PASSED - no issues found!\n")
+    cat("\u2713 Data appears ready for use with logitr()!\n")
+  } else {
+    # Print errors
+    if (length(x$errors) > 0) {
+      cat("\u2717 ERRORS found:\n")
+      for (i in seq_along(x$errors)) {
+        cat("  ", i, ".", x$errors[i], "\n")
+      }
+
+      # Print detailed diagnostics for errors
+      if (!is.null(x$diagnostics$multiple_choice_details)) {
+        cat("\n  Detailed locations for multiple choices:\n")
+        for (obsID in names(x$diagnostics$multiple_choice_details)) {
+          rows <- x$diagnostics$multiple_choice_details[[obsID]]
+          cat("    ObsID", obsID, "- rows:", paste(rows, collapse = ", "), "\n")
+        }
+      }
+
+      if (!is.null(x$diagnostics$no_choice_details)) {
+        cat("\n  Detailed locations for no choices:\n")
+        for (obsID in names(x$diagnostics$no_choice_details)) {
+          rows <- x$diagnostics$no_choice_details[[obsID]]
+          cat("    ObsID", obsID, "- rows:", paste(rows, collapse = ", "), "\n")
+        }
+      }
+
+      if (!is.null(x$diagnostics$noncontiguous_details)) {
+        cat("\n  Detailed locations for non-contiguous obsID blocks:\n")
+        for (obsID in names(x$diagnostics$noncontiguous_details)) {
+          rows <- x$diagnostics$noncontiguous_details[[obsID]]
+          cat(
+            "    ObsID",
+            obsID,
+            "appears in rows:",
+            paste(rows, collapse = ", "),
+            "\n"
+          )
+        }
+      }
+    }
+
+    # Print warnings
+    if (length(x$warnings) > 0) {
+      if (length(x$errors) > 0) {
+        cat("\n")
+      }
+      cat("\u26A0 WARNINGS:\n")
+      for (i in seq_along(x$warnings)) {
+        cat("  ", i, ".", x$warnings[i], "\n")
+      }
+    }
+
+    # Final status
+    cat("\n")
+    if (x$valid) {
+      cat("\u2713 Despite warnings, data structure appears valid for logitr().\n")
+      cat("  Consider addressing warnings for cleaner results.\n")
+    } else {
+      cat(" Please fix the errors above before using with logitr().\n")
+    }
+  }
+
+  invisible(x)
 }
